==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTSUPPLIERSERVICECODEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EQUIPMENTSUPPLIERSERVICECODEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTSUPPLIERSERVICECODEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSUPPLIERPK"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSERVICECODEPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTSUPPLIERSERVICECODEID_Type", propOrder = {
    "equipmentsupplierpk",
    "equipmentservicecodepk"
})
public class EQUIPMENTSUPPLIERSERVICECODEID_Type {

    @XmlElement(name = "EQUIPMENTSUPPLIERPK", required = true)
    protected String equipmentsupplierpk;
    @XmlElement(name = "EQUIPMENTSERVICECODEPK", required = true)
    protected String equipmentservicecodepk;

    /**
     * Obtient la valeur de la propriété equipmentsupplierpk.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTSUPPLIERPK() {
        return equipmentsupplierpk;
    }

    /**
     * Définit la valeur de la propriété equipmentsupplierpk.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTSUPPLIERPK(String value) {
        this.equipmentsupplierpk = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentservicecodepk.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTSERVICECODEPK() {
        return equipmentservicecodepk;
    }

    /**
     * Définit la valeur de la propriété equipmentservicecodepk.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTSERVICECODEPK(String value) {
        this.equipmentservicecodepk = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTSUPPLIERSERVICECODEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EQUIPMENTSUPPLIERSERVICECODEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTSUPPLIERSERVICECODEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSUPPLIERPK"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSERVICECODEPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTSUPPLIERSERVICECODEID_Type", propOrder = {
    "equipmentsupplierpk",
    "equipmentservicecodepk"
})
public class EQUIPMENTSUPPLIERSERVICECODEID_Type {

    @XmlElement(name = "EQUIPMENTSUPPLIERPK", required = true)
    protected String equipmentsupplierpk;
    @XmlElement(name = "EQUIPMENTSERVICECODEPK", required = true)
    protected String equipmentservicecodepk;

    /**
     * Gets the value of the equipmentsupplierpk property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTSUPPLIERPK() {
        return equipmentsupplierpk;
    }

    /**
     * Sets the value of the equipmentsupplierpk property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTSUPPLIERPK(String value) {
        this.equipmentsupplierpk = value;
    }

    /**
     * Gets the value of the equipmentservicecodepk property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTSERVICECODEPK() {
        return equipmentservicecodepk;
    }

    /**
     * Sets the value of the equipmentservicecodepk property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTSERVICECODEPK(String value) {
        this.equipmentservicecodepk = value;
    }

}
